MethodChannelZendeskFlutterPlugin class
An implementation of ZendeskFlutterPluginPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- ZendeskFlutterPluginPlatform
- MethodChannelZendeskFlutterPlugin
Constructors
Properties
- eventChannel → EventChannel
-
The event channel used to receive events from the native platform.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
-
onEvent
→ Stream<
ZendeskEvent> -
Stream of
ZendeskEvents from the native SDK.no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addTicketComment(
{required String requestId, required String body, List< String> attachmentTokens = const []}) → Future<void> -
Add a comment to an existing ticket.
override
-
clearConversationFields(
) → Future< void> -
Clear all conversation fields.
override
-
clearConversationTags(
) → Future< void> -
Clear all conversation tags.
override
-
createTicket(
{required String subject, required String description, List< String> tags = const [], Map<String, String> customFields = const {}, List<String> attachmentTokens = const []}) → Future<ZendeskTicket?> -
Create a new support ticket.
override
-
deleteAttachment(
{required String token}) → Future< void> -
Delete a previously uploaded attachment by its
token.override -
getTicket(
{required String requestId}) → Future< ZendeskTicket?> -
Get a single support ticket by its
requestId.override -
getTicketComments(
{required String requestId}) → Future< List< ZendeskComment> > -
Get comments for a ticket by its
requestId.override -
getTickets(
) → Future< List< ZendeskTicket> > -
Get all support tickets (requests) for the current user.
override
-
getUnreadMessageCount(
) → Future< int> -
Get the current unread message count.
override
-
initialize(
{required String channelKey}) → Future< bool> -
Initialize the Zendesk SDK with the given
channelKey.override -
initializeClassic(
{required String subdomainUrl, required String appId, required String clientId}) → Future< bool> -
Initialize the Classic Zendesk Support SDK.
override
-
isClassicInitialized(
) → Future< bool> -
Check if the Classic Zendesk SDK has been initialized.
override
-
isInitialized(
) → Future< bool> -
Check if the Zendesk SDK has been initialized.
override
-
loginUser(
{required String jwt}) → Future< ZendeskUser?> -
Authenticate a user with the given
jwttoken.override -
logoutUser(
) → Future< void> -
Log out the current user.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setClassicAnonymousIdentity(
) → Future< void> -
Set anonymous identity for the Classic SDK.
override
-
setClassicIdentity(
{required String jwt}) → Future< void> -
Set the user identity for the Classic SDK using a JWT token.
override
-
setConversationFields(
Map< String, String> fields) → Future<void> -
Set conversation fields.
override
-
setConversationTags(
List< String> tags) → Future<void> -
Set conversation tags.
override
-
show(
) → Future< void> -
Show the Zendesk messaging UI.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updatePushNotificationToken(
String token) → Future< void> -
Register a push notification token with the Zendesk SDK.
override
-
uploadAttachment(
{required String fileName, required String filePath, required String mimeType}) → Future< ZendeskAttachment?> -
Upload an attachment and get its token.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited