eventChannel property
The event channel used to receive events from the native platform.
Implementation
@visibleForTesting
final eventChannel = const EventChannel('zendesk_flutter_plus/events');
The event channel used to receive events from the native platform.
@visibleForTesting
final eventChannel = const EventChannel('zendesk_flutter_plus/events');