ZendeskFlutterPluginPlatform class abstract
The interface that implementations of zendesk_flutter_plus must implement.
Platform implementations should extend this class rather than implement it
as ZendeskFlutterPluginPlatform. Extending this class (using extends)
ensures that the subclass will get the default implementation, while
platform implementations that implements this interface will be broken by
newly added ZendeskFlutterPluginPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- ZendeskFlutterPluginPlatform
- Implementers
Constructors
- ZendeskFlutterPluginPlatform()
- Constructs a ZendeskFlutterPluginPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onEvent
→ Stream<
ZendeskEvent> -
Stream of ZendeskEvents from the native SDK.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addTicketComment(
{required String requestId, required String body, List< String> attachmentTokens = const []}) → Future<void> - Add a comment to an existing ticket.
-
clearConversationFields(
) → Future< void> - Clear all conversation fields.
-
clearConversationTags(
) → Future< void> - Clear all conversation tags.
-
createTicket(
{required String subject, required String description, List< String> tags = const [], Map<String, String> customFields = const {}, List<String> attachmentTokens = const []}) → Future<ZendeskTicket?> - Create a new support ticket.
-
deleteAttachment(
{required String token}) → Future< void> -
Delete a previously uploaded attachment by its
token. -
getTicket(
{required String requestId}) → Future< ZendeskTicket?> -
Get a single support ticket by its
requestId. -
getTicketComments(
{required String requestId}) → Future< List< ZendeskComment> > -
Get comments for a ticket by its
requestId. -
getTickets(
) → Future< List< ZendeskTicket> > - Get all support tickets (requests) for the current user.
-
getUnreadMessageCount(
) → Future< int> - Get the current unread message count.
-
initialize(
{required String channelKey}) → Future< bool> -
Initialize the Zendesk SDK with the given
channelKey. -
initializeClassic(
{required String subdomainUrl, required String appId, required String clientId}) → Future< bool> - Initialize the Classic Zendesk Support SDK.
-
isClassicInitialized(
) → Future< bool> - Check if the Classic Zendesk SDK has been initialized.
-
isInitialized(
) → Future< bool> - Check if the Zendesk SDK has been initialized.
-
loginUser(
{required String jwt}) → Future< ZendeskUser?> -
Authenticate a user with the given
jwttoken. -
logoutUser(
) → Future< void> - Log out the current user.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setClassicAnonymousIdentity(
) → Future< void> - Set anonymous identity for the Classic SDK.
-
setClassicIdentity(
{required String jwt}) → Future< void> - Set the user identity for the Classic SDK using a JWT token.
-
setConversationFields(
Map< String, String> fields) → Future<void> - Set conversation fields.
-
setConversationTags(
List< String> tags) → Future<void> - Set conversation tags.
-
show(
) → Future< void> - Show the Zendesk messaging UI.
-
toString(
) → String -
A string representation of this object.
inherited
-
updatePushNotificationToken(
String token) → Future< void> - Register a push notification token with the Zendesk SDK.
-
uploadAttachment(
{required String fileName, required String filePath, required String mimeType}) → Future< ZendeskAttachment?> - Upload an attachment and get its token.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ ZendeskFlutterPluginPlatform
-
The default instance of ZendeskFlutterPluginPlatform to use.
getter/setter pair